library risecx_chat_client;

import 'package:flutter/material.dart';
import 'package:risecx_chat_client/models/configuration_model.dart';
import 'package:risecx_chat_client/models/user_model.dart';
import 'package:risecx_chat_client/widgets/chat/programs/programs.dart';
import 'package:risecx_chat_client/widgets/widgets.dart';
import 'blocs/blocs.dart';

class RisecxChatClient extends StatefulWidget {
  final dynamic user;
  final dynamic options;
  const RisecxChatClient({Key key, @required this.user, @required this.options})
      : super(key: key);

  @override
  _RisecxChatClientState createState() => _RisecxChatClientState();
}

class _RisecxChatClientState extends State<RisecxChatClient> {
  ChatBloc _chatBloc;
  int _currentIndex = 0;
  List<Widget> _children = [];

  @override
  void initState() {
    super.initState();
    ConfigurationModel configurationModel = ConfigurationModel(
        urlApi: widget.options['urlApi'],
        botName: widget.options['botName'],
        wsUrl: widget.options['wsUrl'],
        avatarImage: widget.options['avatarImage'] ??
            'assets/images/default_bot_avatar.jpg');
    _chatBloc = new ChatBloc(configurationModel);

    _children = [
      ChatClientWidget(
        chatBloc: _chatBloc,
        user: UserModel.fromJson(widget.user),
        config: configurationModel,
      ),
      FavoriteWidgets(_chatBloc, UserModel.fromJson(widget.user),
          onPayloadPress: _onFavoritePayloadPress),
      Container(
          child: ProgramsWidget(
              bloc: _chatBloc, user: UserModel.fromJson(widget.user))),
    ];
  }

  _onTabTap(int tabIndex) {
    setState(() {
      _currentIndex = tabIndex;
    });
  }

  _onFavoritePayloadPress(payload) {
    print('_onFavoritePayloadPress $payload');
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: <Widget>[
        Expanded(child: _children[_currentIndex]),
        BottomNavigationBar(
          currentIndex: _currentIndex,
          onTap: _onTabTap,
          items: [
            BottomNavigationBarItem(
              icon: new Icon(Icons.chat),
              title: new Text('Chat'),
            ),
            BottomNavigationBarItem(
              icon: new Icon(Icons.favorite),
              title: new Text('Favorites'),
            ),
            BottomNavigationBarItem(
                icon: Icon(Icons.filter_list), title: Text('Programs'))
          ],
        ),
      ],
    );
  }
}
